<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Stäng (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Fäll in</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Fäll ut</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Stäng varning</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% av %Ln minut</numerusform>
            <numerusform>%1% av %Ln minuter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% av %Ln ord</numerusform>
            <numerusform>%1% av %Ln ord</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln ord</numerusform>
            <numerusform>%Ln ord</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minuter</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dagliga framsteg</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Längsta svit</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Pågående svit</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dag</numerusform>
            <numerusform>%n dagar</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% av dagligt mål</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Ställ in språk</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Namnlös %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Skrivskyddad)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Tyvärr</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Kunde inte spara &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Spara fil som</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Kunde inte skriva över &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Byt namn på fil</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Kunde inte byta namn på filen &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Läs om fil?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Läs om filen &quot;%1&quot; från disk?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Alla osparade ändringar kommer att gå förlorade.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Läs om</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Namnlös %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Att spara som vanlig text tar bort all formatering. Ta bort formatering?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Filen ändrad</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Filen &quot;%1&quot; har ändrats av ett annat program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Vill du läsa om filen?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Läs om</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorera</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Fil raderad</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Filen %1 togs bort av ett annat program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Vill du spara eller stänga filen?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kunde inte öppna arkiv.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Ersätt med:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorera skiftläge</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Endast hela ord</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Reguljära uttryck</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Sök uppåt</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Sök nedåt</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Sök</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Ersätt</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Ersätt &amp;alla</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersätt</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Ersätt %n förekomst?</numerusform>
            <numerusform>Ersätt %n förekomster?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Tyvärr</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frasen hittades inte.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument text</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Vanlig text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Alla filer som stöds</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Kontrollera stavning...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Inga förslag hittades)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Öppna bild</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Bilder(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Välj programspråk:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemspråk&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Observera</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Starta om programmet för att språkändringen ska aktiveras.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kunde inte öppna arkiv</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Verktygsrad</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Stavningskontroll</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Välj ordbok</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Tyvärr</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kunde inte öppna arkivet.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arkivet innehåller ingen användbar ordbok.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Genvägar</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Genvägar i konflikt. Vill du fortsätta?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Ordboken &quot;%1&quot; finns redan. Vill du ersätta den?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dagligt mål</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Inget</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuter:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Ord:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Redigering</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centrera alltid vertikalt</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blockmarkör för infogning</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Mjuka typsnitt</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Skrivmaskinsljud</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Smarta citationstecken:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dubbel</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scener</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Avdelare:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Kom ihåg markörposition</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Antal ord</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Antal sidor</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Antal stycken</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Antal tecken</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Tecken:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Stycken:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritm för ordantal</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Återställ dagligt mål för idag till noll?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Ta bort aktuell ordlista?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Skriv byteordningsmärke i vanliga textfiler</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Standardformat:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Användargränssnitt</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Visa alltid rullist</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Visa alltid topplist</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Visa alltid bottenlist</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Återställ idag</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Kom ihåg historik</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Visa sviter</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minsta framsteg för sviter:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Identifiera ordgränser</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dela teckenantal med sex</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Räkna varje bokstav som ett ord</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Sidräkningsalgoritm</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Endast ikoner</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Endast text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text bredvid ikoner</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text under ikoner</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Textposition:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Åtgärder</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Flytta uppåt</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Flytta nedåt</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Lägg till avgränsare</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Genväg</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Åtgärd</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Kontrollera stavning när du skriver</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorera ord med VERSALER</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorera ord med siffror</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Personlig ordbok</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Inte en stödd RTF-fil.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Nådde oväntat filslut.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Skift+Ned</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Flytta upp scener</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Skift+Upp</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Växla scenlista</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Skift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Visa scenlista (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Dölj scenlista (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Flytta ner scener</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Storleksändra scenlista</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Hantera sessioner</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essioner</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Växla till</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Ny session</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplicera session</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Byt namn på session</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Ta bort markerad session?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Sessionsnamn:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Tyvärr</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Det begärda sessionsnamnet används redan.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Ny...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Hantera...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Töm</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Återställ till förval</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Genväg:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Ersätter citationstecken...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vänta</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Kontrollera stavning</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Lägg till</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorera</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorera alla</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Ändra</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Ä&amp;ndra alla</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Finns inte i ordboken:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Ändra till:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Kontrollerar stavning...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Vänta</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Fortsätt kontrollera i början av filen?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Stavningskontrollen är färdig.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symboler</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nyligen använda symboler</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Alla symboler</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Infoga</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Tecken</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skriftspråk</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Namnlös %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Ingen bild</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Sida vid sida</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrerad</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Utsträckt</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Skalad</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoomad</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacitet:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredd:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Runda textbakgrundshörn</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radie:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Gör textbakgrund suddig</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Texbakgrundsskugga</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Vertikal förskjutning:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Marginaler</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Fönster:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Sida:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Gör indrag första raden</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Ovanför:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Under:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Redigera tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fönsterbakgrund</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Färg:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Bild:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> bildpunkter</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Textbakgrund</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Typsnitt:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Felstavning:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Radavstånd</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkelt</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 radavstånd</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dubbelt</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportionellt</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Styckeavstånd</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tabbredd:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nytt tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Teman</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bittra himlar</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Förtrollning</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Mjukblått</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Gamla skolan</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Rymddrömmar</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spionspel</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Fridfullhet</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Skrivbord</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nytt</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Anpassade</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Ta bort tema &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Teman (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importera tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportera tema</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Ta bort tidtagare?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Ord:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Sidor:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Stycken:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Tecken:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ställ in fördröjning</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ställ in tid</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Fördröjning:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH: mm: ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Inga tidtagare är igång</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Tidtagare</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Tidigare</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Avbryt redigering av tidtagare?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Läser in teman</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Läser in ljud</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Namnlös</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Om FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>En enkel ordbehandlare med helskärmsläge</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Släppt under licensen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Använder ikoner från ikontemat &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Använda under licensen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Tecken: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Sidor: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Stycken: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Ord: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Öppnar %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Namnlös %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Lista alla dokument</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Växla till nästa dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Växla till föregående dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Växla till första dokumentet</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Växla till sista dokumentet</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Växla till dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Läser in inställningar</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Nödcachen är inte skrivbar.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter stängdes inte av korrekt.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Återställ från nödcachen?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Några filer kunde inte öppnas.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Några filer öppnades som skrivskyddade.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&quot;%1&quot; är nyare än den mellanlagrade kopian.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Skriv över nyare fil?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Spara ändringar?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Spara ändringar till filen &quot;%1&quot; innan stängning?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Dina ändringar kommer att förloras om du inte sparar dem.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Kunde inte läsa in skrivmaskinsljud.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nytt</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öppna...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Läs in &amp;igen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Spara</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Spara so&amp;m...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Byt namn...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Spara a&amp;lla</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Hantera sessioner</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Ny session</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Skriv &amp;ut...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Si&amp;dinställning...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;täng</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>A&amp;vsluta</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;edigera</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ångra</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Gör om</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Klipp &amp;ut</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiera</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Klistra &amp;in</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Klistra in &amp;oformaterat</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Skift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Markera &amp;allt</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Välj &amp;scen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Skift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmatera</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Rubrik</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Rubrik &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Rubrik &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Rubrik &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Rubrik &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Rubrik &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Rubrik &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Fet</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Understruken</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>G&amp;enomstruken</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Upphö&amp;jd</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Nedsän&amp;kt</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Justera &amp;vänster</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Justera &amp;mitten</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Justera &amp;höger</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justera</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Minska indrag</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Öka in&amp;drag</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Vänster till &amp;högerblock</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Höger till &amp;vänsterblock</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Ver&amp;ktyg</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Sök...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Sök &amp;nästa</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Sök &amp;föregående</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Ersätt...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Smarta &amp;citationstecken</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Uppdatera &amp;dokument</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Uppdatera dokument smarta citationstecken</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Uppdatera &amp;markering</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Uptatera markering smarta citationstecken</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Sta&amp;vning...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Ställ in &amp;Språk...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Tidtagare...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboler...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dagliga framsteg</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Inställningar</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Visa &amp;verktygsrad</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Visa &amp;menyikoner</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>F&amp;okuserad text</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Helskärm</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Mi&amp;nimera</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Teman...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Inställningar...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fokus av</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokusera en rad</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokusera tre rader</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Stycke</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokusera stycke</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programs&amp;pråk...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Några filer stöds inte och kunde inte öppnas.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Av</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>En &amp;rad</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tre rader</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
</context>
</TS>
